<?php
namespace WaveeCore\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}



/**
 * Text Typing Effect
 *
 * Elementor widget for text typing effect.
 *
 * @since 1.7.0
 */
class Wavee_animated_images extends Widget_Base {

    public function get_name() {
        return 'wavee_animated_images';
    }

    public function get_title() {
        return __( 'Animated Images', 'wavee-core' );
    }

    public function get_icon() {
        return 'eicon-image-hotspot';
    }

    public function get_categories() {
        return [ 'wavee-elements' ];
    }

    protected function register_controls() {


        // -------------------------- Select Style  ----------------------------------//
        $this->start_controls_section(
            'select_style', [
                'label' => __( 'Select Style', 'wavee-core' ),
            ]
        );

        $this->add_control(
            'style', [
                'label' => esc_html__( 'Style', 'wavee-core' ),
                'type' => Controls_Manager::SELECT,
                'label_block' => true,
                'options' => [
                    '1' => esc_html__('Style One', 'wavee-core'),
                    '2' => esc_html__('Style Two', 'wavee-core'),
                    '3' => esc_html__('Style Three', 'wavee-core'),
                ],
                'default' => '1'
            ]
        );

        $this->end_controls_section(); // End Style


        // ------------------------------------------- Start Featured Image -----------------------------------------//
        $this->start_controls_section(
            'featured_images_sec', [
                'label' => __( 'Featured Images', 'wavee-core' ),
            ]
        );

        $this->add_control(
            'fimage', [
                'label' => esc_html__( 'Image', 'wavee-core' ),
                'type' => Controls_Manager::MEDIA,
                'condition' => [
                    'style' => [ '1', '2' ]
                ]
            ]
        );

        $this->add_control(
            'fimage2', [
                'label' => esc_html__( 'Image 02', 'wavee-core' ),
                'type' => Controls_Manager::MEDIA,
                'condition' => [
                    'style' => '1'
                ]
            ]
        );

        $image = new \Elementor\Repeater();

        $image->add_control(
            'align_items', [
                'type' => \Elementor\Controls_Manager::HIDDEN,
            ]
        );

        $image->add_control(
            'image', [
                'label' => esc_html__( 'Images', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );

        $this->add_control(
            'featured_images', [
                'label' => esc_html__( 'Add Image', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' => $image->get_controls(),
                'title_field' => '{{{ align_items }}}',
                'condition' => [
                    'style' => '3'
                ]
            ]
        );

        $this->end_controls_section(); // End Featured Images


        // ------------------------------------------- Start Shape Images -----------------------------------------//
        $this->start_controls_section(
            'shape_images_sec', [
                'label' => __( 'Shape Images', 'wavee-core' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'shape1', [
                'label' => esc_html__( 'Shape', 'wavee-core' ),
                'type' => Controls_Manager::MEDIA,
                'condition' => [
                    'style' => [ '1', '2', '3' ]
                ]
            ]
        );

        $this->add_control(
            'shape2', [
                'label' => esc_html__( 'Shape 02', 'wavee-core' ),
                'type' => Controls_Manager::MEDIA,
                'condition' => [
                    'style' => [ '1', '2', '3' ]
                ]
            ]
        );

        $this->add_control(
            'shape3', [
                'label' => esc_html__( 'Shape 03', 'wavee-core' ),
                'type' => Controls_Manager::MEDIA,
                'condition' => [
                    'style' => [ '1', '2' ]
                ]
            ]
        );

        $this->end_controls_section(); // End Shape Images


        // ----------------------------------- Start Shape Images ---------------------------------------//
        $this->start_controls_section(
            'sec_bg_style', [
                'label' => __( 'Section Background', 'wavee-core' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'bg_color', [
                'label'     => esc_html__('Background Color 01', 'wavee-core'),
                'type'      => Controls_Manager::COLOR,
            ]
        );

        $this->add_control(
            'bg_color_01', [
                'label'     => esc_html__('Background Color 02', 'wavee-core'),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '.bg-color-1' => 'background-image: -webkit-radial-gradient(50% 50%, circle closest-side, {{bg_color.VALUE}} 0%, {{VALUE}} 100%) !important;',
                ],
                'condition' => [
                    'style' => '1'
                ]
            ],
        );

        $this->add_control(
            'bg_color_02', [
                'label'     => esc_html__('Background Color 02', 'wavee-core'),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '.bg-color-2' => 'background-image: -webkit-radial-gradient(50% 50%, circle closest-side, {{bg_color.VALUE}} 0%, {{VALUE}} 100%) !important;',
                ],
                'condition' => [
                    'style' => '2'
                ]
            ],
        );

        $this->add_control(
            'bg_color_03', [
                'label'     => esc_html__('Background Color 02', 'wavee-core'),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '.bg-color-3' => 'background-image: -webkit-radial-gradient(50% 50%, circle closest-side, {{bg_color.VALUE}} 0%, {{VALUE}} 100%) !important;',
                ],
                'condition' => [
                    'style' => '3'
                ]
            ],
        );

        $this->end_controls_section(); // End Shape Images

    }

    protected function render() {
        $settings = $this->get_settings_for_display();
        extract($settings); //Array to variable conversation

        if ( !empty($settings['style'] == '1') ) {
            if ( !empty($settings['shape1']['id']) ) {
                echo wp_get_attachment_image($settings['shape1']['id'], 'full', '', array(  'class' => 'p_absoulte left_round layer', 'data-depth' => '0.1' ));
            }
            if ( !empty($settings['shape2']['id']) ) {
                echo wp_get_attachment_image($settings['shape2']['id'], 'full', '', array(  'class' => 'p_absoulte left_triangle' ));
            }
            ?>
            <div class="big_rounds"></div>
            <div class="dot_left small_round"></div>
            <div class="dot_left big_round"></div>
            <div class="multi_left_img">
                <?php
                if ( !empty($settings['shape3']['id']) ) {
                    echo wp_get_attachment_image($settings['shape3']['id'], 'full', '', array(  'class' => 'p_absoulte left_dot' ));
                }
                ?>
                <div class="w_phone_img">
                    <?php
                    if ( !empty($settings['fimage']['id']) ) {
                        echo wp_get_attachment_image($settings['fimage']['id'], 'full', '', array(  'class' => 'p_one layer', 'data-depth' => '0.1' ));
                    }
                    if ( !empty($settings['fimage2']['id']) ) {
                        echo wp_get_attachment_image($settings['fimage2']['id'], 'full', '', array(  'class' => 'p_two p_absoulte' ));
                    }
                    ?>
                </div>
            </div>
            <?php
        }

        if ( !empty($settings['style'] == '2') ) {
            if ( !empty($settings['shape1']['id']) ) {
                echo wp_get_attachment_image($settings['shape1']['id'], 'full', '', array(  'class' => 'p_absoulte left_round' ));
            }
            if ( !empty($settings['shape2']['id']) ) {
                echo wp_get_attachment_image($settings['shape2']['id'], 'full', '', array(  'class' => 'p_absoulte left_triangle' ));
            }
            ?>
            <div class="big_rounds"></div>
            <div class="dot_left small_round"></div>
            <div class="dot_left big_round"></div>
            <div class="multi_left_img">
                <?php
                if ( !empty($settings['fimage']['id']) ) {
                    echo wp_get_attachment_image($settings['fimage']['id'], 'full', '', array(  'class' => 'laptop_m' ));
                }
                if ( !empty($settings['shape3']['id']) ) {
                    echo wp_get_attachment_image($settings['shape3']['id'], 'full', '', array(  'class' => 'p_absoulte left_dot' ));
                }
                ?>
            </div>
            <?php
        }

        if ( !empty($settings['style'] == '3') ) {
            if ( !empty($settings['shape1']['id']) ) {
                echo wp_get_attachment_image($settings['shape1']['id'], 'full', '', array(  'class' => 'p_absoulte left_round' ));
            }
            if ( !empty($settings['shape2']['id']) ) {
                echo wp_get_attachment_image($settings['shape2']['id'], 'full', '', array(  'class' => 'p_absoulte left_triangle' ));
            }
            ?>
            <div class="big_rounds"></div>
            <div class="dot_left small_round"></div>
            <div class="dot_left big_round"></div>
            <div class="multi_left_img">
                <div class="w_mockup_img">
                    <?php
                    if ( !empty($settings['featured_images']) ) {
                        foreach ( $settings['featured_images'] as $index => $image ) {
                            switch($index) {
                                case 0:
                                    $align_class = 'img_screen one';
                                    break;
                                case 1:
                                    $align_class = 'img_screen two';
                                    break;
                                case 2:
                                    $align_class = 'img_screen three';
                                    break;
                                case 3:
                                    $align_class = 'img_four';
                                    break;
                            }
                            ?>
                            <div class="<?php echo esc_attr( $align_class ); ?>">
                                <?php echo wp_get_attachment_image( $image['image']['id'], 'full' ) ?>
                            </div>
                            <?php
                        }
                    }
                    ?>
                </div>
            </div>
            <?php
        }
    }
}