<?php
namespace WaveeCore\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

/**
 * Text Typing Effect
 *
 * Elementor widget for text typing effect.
 *
 * @since 1.7.0
 */
class Wavee_split_contents extends Widget_Base {

    public function get_name() {
        return 'wavee_split_contents';
    }

    public function get_title() {
        return __( 'Split Contents', 'wavee-core' );
    }

    public function get_icon() {
        return 'eicon-banner';
    }

    public function get_style_depends() {
        //return [ 'jquery-multiscroll' ];
        return [ 'jquery-multiscroll' ];
    }

    public function get_script_depends() {
        //return [ 'jquery-easings', 'multiscroll', /*'multiscroll-extensions',*/ 'multi', 'wavee-home-split' ];
        return [ 'jquery-easings', 'multiscroll', 'multiscroll-extensions', 'multi', 'wavee-home-split' ];
    }

    public function get_categories() {
        return [ 'wavee-elements' ];
    }

    protected function register_controls() {

        // ------------------------------------ Start Split Contents -----------------------------------------//
        $this->start_controls_section(
            'split_contents_sec', [
                'label' => __( 'Split Contnents', 'wavee-core' ),
            ]
        );

        $repeater = new \Elementor\Repeater();

        $repeater->add_control(
            'align_items', [
                'type' => \Elementor\Controls_Manager::HIDDEN,
            ]
        );

        $repeater->add_control(
            'split_left_content', [
                'label' => __( 'Left Contents', 'wavee-core' ),
                'type' => \Elementor\Controls_Manager::SELECT2,
                'options' => split_post_contents(),
                'label_block' => true,
            ]
        );

        $repeater->add_control(
            'split_right_content', [
                'label' => __( 'Right Contents', 'wavee-core' ),
                'type' => \Elementor\Controls_Manager::SELECT2,
                'options' => split_post_contents(),
                'label_block' => true,
            ]
        );

        $this->add_control(
            'split_contents', [
                'label' => __( 'Add Split Content', 'wavee-core' ),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'title_field' => '{{{ align_items }}}',
                'prevent_empty' => false,
            ]
        );

        $this->end_controls_section(); // End Split Contents



        // -------------------------------- Start Footer Area -----------------------------------------//
        $this->start_controls_section(
            'footer_sec', [
                'label' => __( 'Footer Contents', 'wavee-core' ),
            ]
        );

        $repeater = new \Elementor\Repeater();
        $repeater->add_control(
            'icon', [
                'label' => __( 'Social Icon', 'wavee-core' ),
                'type' => \Elementor\Controls_Manager::ICONS,
                'default' => [
                    'value' => 'fa fa-facebook',
                    'library' => 'solid',
                ],
            ]
        );

        $repeater->add_control(
            'icon_url', [
                'label' => __( 'Icon URL', 'wavee-core' ),
                'type' => \Elementor\Controls_Manager::URL,
                'default' => [
                    'url' => '#'
                ],
            ]
        );

        $this->add_control(
            'social_icons', [
                'label' => __( 'Add Icon', 'wavee-core' ),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'title_field' => '{{{ icon.value }}}',
                'prevent_empty' => false,
            ]
        );

        $this->add_control(
            'prev_text', [
                'label' => __( 'Previous Text', 'wavee-core' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => 'Prev'
            ]
        );

        $this->add_control(
            'next_text', [
                'label' => __( 'Next Text', 'wavee-core' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => 'Next'
            ]
        );

        $this->end_controls_section(); // End Social links

    }

    protected function render() {
        $settings = $this->get_settings_for_display();
        ?>
        <section id="multiscroll" class="fullpage_main_area ms-section">
            <div class="ms-left">
                <?php
                $left_data_id = 1;
                $left_id = 1;
                if ( !empty($settings['split_contents']) ) {
                    foreach ( $settings['split_contents'] as $split_content ) {
                        $left_content = $split_content['split_left_content'];
                        ?>
                        <div class="ms-section comon" data-id="<?php echo esc_attr($left_data_id) ?>" id="left<?php echo esc_attr($left_id++) ?>">
                            <?php echo \Elementor\Plugin::$instance->frontend->get_builder_content_for_display($left_content); ?>
                        </div>
                        <?php
                        $left_data_id = $left_data_id + 2;
                    }
                }
                ?>
            </div>
            <div class="ms-right">
                <?php
                $right_data_id = 2;
                $right_id = 1;
                if ( !empty($settings['split_contents']) ) {
                    foreach ( $settings['split_contents'] as $split_content ) {
                        $right_content = $split_content['split_right_content'];
                        ?>
                        <div class="ms-section comon" data-id="<?php echo esc_attr($right_data_id) ?>" id="right<?php echo esc_attr($right_id++) ?>">
                            <?php echo \Elementor\Plugin::$instance->frontend->get_builder_content_for_display($right_content); ?>
                        </div>
                        <?php
                        $right_data_id = $right_data_id + 2;
                    }
                }
                ?>
            </div>
        </section>

        <footer class="full_footer full_footer_dark position-fixed">
            <div class="container-fluid">
                <div class="row">
                    <div class="col-sm-6 col-6">
                        <ul class="list-unstyled social_icon social_icon_two">
                            <?php
                            if ( !empty($settings['social_icons']) ) {
                                foreach ( $settings['social_icons'] as $social_icon ) {
                                    ?>
                                    <li>
                                        <a href="<?php echo esc_url($social_icon['icon_url']['url']) ?>">
                                            <?php \Elementor\Icons_Manager::render_icon( $social_icon['icon'] ); ?>
                                        </a>
                                    </li>
                                    <?php
                                }
                            }
                            ?>
                        </ul>
                    </div>
                    <div class="col-sm-6 col-6">
                        <div class="pr_details_nav h_slider_nav h_slider_nav_two align-items-center">
                            <span class="prev" id="moveUp"><?php echo esc_html($settings['prev_text']) ?></span>
                            <span class="next moveUp" id="moveDown"><?php echo esc_html($settings['next_text']) ?></span>
                        </div>
                    </div>
                </div>
            </div>
        </footer>

        <script>
            ;(function($) {
                "use strict";
                $(document).ready( function () {

                    if ($('#wavescroll').length > 0) {
                        $('#moveDown').click(function () {
                            $.fn.fullpage.moveSectionDown();
                        });
                        $('#moveUp').click(function () {
                            $.fn.fullpage.moveSectionUp();
                        });
                    }

                })
            })(jQuery);
        </script>

        <?php
    }
}