<?php

/**
 * Register Google fonts.
 *
 * @return string Google fonts URL for the theme.
 */
function wavee_fonts_url() {
    $fonts_url = '';
    $fonts     = array();
    $subsets   = '';

    /* translators: If there are characters in your language that are not supported by this font, translate this to 'off'. Do not translate into your own language. */
    if ( 'off' !== esc_html_x( 'on', "Poppins font: on or off", 'wavee' ) ) {
        $fonts[] = "Poppins:300,400,500,600,700,900";
    }

    $is_ssl = is_ssl() ? 'https' : 'http';

    if (  $fonts  ) {
        $fonts_url = add_query_arg( array(
            'family' => urlencode( implode( '|', $fonts  ) ),
            'subset' => urlencode( $subsets ),
        ), "$is_ssl://fonts.googleapis.com/css" );
    }

    return $fonts_url;
}

function wavee_scripts() {
    $opt = get_option( 'wavee_opt' );

    wp_enqueue_style( 'wavee-fonts', wavee_fonts_url(), array(), null );

    if ( is_rtl() ) {
        wp_enqueue_style( 'bootstrap-rtl', esc_url(WAVEE_DIR_VEND.'/bootstrap/css/bootstrap-rtl.min.css' ) );
    } else {
        wp_enqueue_style('bootstrap', esc_url(WAVEE_DIR_VEND . '/bootstrap/css/bootstrap.min.css'));
    }

    wp_enqueue_style( 'elagent-icon',  WAVEE_DIR_VEND . '/elagent-icon/style.css' );
    wp_enqueue_style( 'fontawesome',  WAVEE_DIR_VEND. '/font-awesome/css/all.css' );
    wp_enqueue_style( 'magnific-popup',  WAVEE_DIR_VEND . '/magnify-popup/magnific-popup.css' );
    wp_enqueue_style( 'slick',  WAVEE_DIR_VEND . '/slick/slick.css' );
    wp_enqueue_style( 'slick-theme',  WAVEE_DIR_VEND . '/slick/slick-theme.css' );
    wp_enqueue_style( 'mediaelementplayer',  WAVEE_DIR_VEND . '/player-audio/mediaelementplayer.css' );
    wp_enqueue_style( 'animate',  WAVEE_DIR_VEND . '/animation/animate.css' );

    wp_enqueue_style( 'wavee-wpd',  WAVEE_DIR_CSS.'/wpd-style.css' );

    if ( is_rtl() ) {
        wp_enqueue_style( 'wavee-main', esc_url(WAVEE_DIR_CSS . '/rtl.css'), array('wavee-wpd') );
    }

    if ( !is_rtl() ) {
        if ( is_page_template('page-full-screen-slider.php') || is_page_template('page-full-screen-slider-two.php') || is_page_template('page-full-screen-slider-three.php')) {
            wp_enqueue_style('wavee-main', esc_url(WAVEE_DIR_CSS . '/style.css'), array('fullpage'));
        } else {
            wp_enqueue_style('wavee-main', esc_url(WAVEE_DIR_CSS . '/style.css'), array( 'wavee-wpd' ));
        }
    }

    if ( is_404() ) {
        wp_enqueue_style( 'wavee-404', WAVEE_DIR_CSS . '/404.css' );
    }

    wp_register_style( 'wavee-custom-animation', WAVEE_DIR_CSS . '/custom-animation.css' );
    if ( defined( 'ELEMENTOR_VERSION') ) {
        if ( !\Elementor\Plugin::$instance->preview->is_preview_mode() ) {
            wp_enqueue_style( 'wavee-custom-animation' );

        }
    }

    wp_enqueue_style( 'wavee-wp-custom', WAVEE_DIR_CSS . '/wp-custom.css' );
    wp_enqueue_style( 'wavee-root', get_stylesheet_uri() );

    // WooCommerce
    if ( class_exists( 'WooCommerce' ) ) {
        // Register Style
        wp_register_style( 'nice-select', WAVEE_DIR_VEND.'/nice-select/nice-select.css' );
        wp_register_style( 'themify-icons', WAVEE_DIR_VEND.'/themify-icon/themify-icons.css' );
        wp_register_style( 'wavee-shop', WAVEE_DIR_CSS.'/shop.css' );
        wp_register_style( 'wavee-checkout', WAVEE_DIR_CSS.'/checkout.css' );
        wp_register_style( 'wavee-shop-my-account', WAVEE_DIR_CSS.'/shop-my_account.css' );

        if ( is_shop() || is_tax( 'product_cat' ) || is_singular( 'product' ) || is_tax( 'product_tag' ) || is_cart() ) {
            wp_enqueue_style( 'themify-icons' );
            wp_enqueue_style( 'wavee-shop' );
        }

        if ( is_checkout() ) {
            wp_enqueue_style( 'wavee-shop' );
            wp_enqueue_style( 'wavee-checkout' );
        }

        if ( function_exists('is_wishlist') ) {
            if ( is_wishlist() ) {
                wp_enqueue_style( 'themify-icons' );
                wp_enqueue_style( 'wavee-shop' );
            }
        }

        if ( is_account_page() ) {
            wp_enqueue_style( 'wavee-shop-my-account' );
        }

        if ( is_shop() || is_tax( 'product_cat' ) || is_tax( 'product_tag' ) ) {
            wp_enqueue_style( 'nice-select' );
        }
    }

    wp_enqueue_style('wavee-responsive', esc_url(WAVEE_DIR_CSS . '/responsive.css'));
    wp_enqueue_style( 'wavee-responsive-2',  WAVEE_DIR_CSS . '/responsive-2.css' );

    // Inline CSS Render File
    require get_template_directory() . '/inc/wavee_css_render.php';

    /**
     * Enqueue Scripts File
     */
    wp_enqueue_script( 'popper', WAVEE_DIR_VEND .'/bootstrap/js/popper.min.js', array( 'jquery' ), '1.0', true );
    wp_enqueue_script( 'bootstrap', WAVEE_DIR_VEND .'/bootstrap/js/bootstrap.min.js', array( 'jquery' ), '4.3.1', true );
    wp_enqueue_script( 'wow', WAVEE_DIR_VEND .'/wow/wow.min.js', array( 'jquery' ), '1.1.3', true );


    wp_enqueue_script( 'parallaxie', WAVEE_DIR_JS .'/parallaxie.js', array( 'jquery' ), '0.5', true );
    wp_enqueue_script( 'particles', WAVEE_DIR_VEND .'/particale/particles.js', array( 'jquery' ), '2.0.0', true );
    wp_enqueue_script( 'magnific-popup', WAVEE_DIR_VEND .'/magnify-popup/jquery.magnific-popup.min.js', array( 'jquery' ), '1.1.0', true );
    wp_enqueue_script( 'parallax', WAVEE_DIR_JS .'/parallax.js', array( 'jquery' ), '1.0', true );
    wp_enqueue_script( 'slick', WAVEE_DIR_VEND .'/slick/slick.min.js', array( 'jquery' ), '1.0', true );
    wp_enqueue_script( 'mediaelement-and-player', WAVEE_DIR_VEND .'/player-audio/mediaelement-and-player.min.js', array( 'jquery' ), '4.2.6', true );
    wp_enqueue_script( 'wavee-custom', WAVEE_DIR_JS .'/custom.js', array( 'jquery' ), '1.0', true );


	// WooCommerce
	if ( class_exists( 'WooCommerce' ) ) {
		// Register Scripts
		wp_register_script( 'nice-select', WAVEE_DIR_VEND.'/nice-select/jquery.nice-select.min.js', array( 'jquery' ), '1.0', true );

		if ( is_shop() || is_tax( 'product_cat' ) || is_tax( 'product_tag' ) ) {
			wp_enqueue_script( 'nice-select' );
		}
	}

    // Inline JS
    $dynamic_js = '';
    wp_add_inline_script( 'wavee-custom-wp', $dynamic_js);

    if (  is_singular() && comments_open() && get_option( 'thread_comments'  )  ) {
        wp_enqueue_script( 'comment-reply' );
    }
}

add_action( 'wp_enqueue_scripts', 'wavee_scripts', 99 );

/**
 * Admin dashboard style and scripts
 */
add_action( 'admin_enqueue_scripts', function() {
    global $pagenow;
    wp_enqueue_style( 'wavee-admin', WAVEE_DIR_CSS . '/admin.min.css' );
});